'use strict';

var _enzyme = require('enzyme');

var _history = require('history');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRouterDom = require('react-router-dom');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('src | components | pages | hocs | withQuery', function () {
  describe('snapshot', function () {
    it('should match snapshot', function () {
      // when
      var wrapper = (0, _enzyme.shallow)(_react2.default.createElement(_utils.QueryRouterTest, null));

      // then
      expect(wrapper).toBeDefined();
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('query', function () {
    describe('params', function () {
      it('withQuery passes a query.params object that formats the location search string into in a params object', function () {
        // given
        var history = (0, _history.createBrowserHistory)();
        history.push('/test?page=1&keywords=test&orderBy=offer.id+desc');

        // when
        var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
          _reactRouterDom.Router,
          { history: history },
          _react2.default.createElement(
            _reactRouterDom.Route,
            { path: '/test' },
            _react2.default.createElement(_utils.QueryRouterTest, null)
          )
        ));

        // then

        var _wrapper$find$props = wrapper.find('Test').props(),
            query = _wrapper$find$props.query;

        var expectedParams = {
          keywords: "test",
          orderBy: "offer.id desc",
          page: "1"
        };
        expect(query.params).toEqual(expectedParams);
      });
    });

    describe('translatedParams', function () {
      it('withQuery passes query.translatedParams object that transforms params into translated params thanks to a mapper', function () {
        // given
        var history = (0, _history.createBrowserHistory)();
        history.push('/test?lieu=AE');
        var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
          _reactRouterDom.Router,
          { history: history },
          _react2.default.createElement(
            _reactRouterDom.Route,
            { path: '/test' },
            _react2.default.createElement(_utils.FrenchQueryRouterTest, null)
          )
        ));
        var props = wrapper.find('Test').props();

        // when
        var translatedQueryParams = props.query.translatedParams;

        // then
        var expectedTranslatedQueryParams = {
          venue: "AE"
        };
        expect(translatedQueryParams).toEqual(expectedTranslatedQueryParams);
      });
    });

    describe('getSearchFromUpdate', function () {
      it('withQuery passes query.getSearchFromUpdate that overwrites the location.search', function () {
        // given
        var history = (0, _history.createBrowserHistory)();
        history.push('/test?page=1&keywords=test');
        var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
          _reactRouterDom.Router,
          { history: history },
          _react2.default.createElement(
            _reactRouterDom.Route,
            { path: '/test' },
            _react2.default.createElement(_utils.QueryRouterTest, null)
          )
        ));

        var _wrapper$find$props2 = wrapper.find('Test').props(),
            query = _wrapper$find$props2.query;

        // when


        var search = query.getSearchFromUpdate({ keywords: null, page: 2 });

        // then
        expect(search).toStrictEqual('?page=2');
      });
    });

    describe('getSearchFromAdd', function () {
      it('withQuery passes query.getSearchFromAdd function that concatenates values in the location.search', function () {
        // given
        var history = (0, _history.createBrowserHistory)();
        history.push('/test?jours=0,1&keywords=test');
        var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
          _reactRouterDom.Router,
          { history: history },
          _react2.default.createElement(
            _reactRouterDom.Route,
            { path: '/test' },
            _react2.default.createElement(_utils.QueryRouterTest, null)
          )
        ));

        var _wrapper$find$props3 = wrapper.find('Test').props(),
            query = _wrapper$find$props3.query;

        // when


        var search = query.getSearchFromAdd('jours', '2');

        // then
        expect(search).toStrictEqual('?jours=0%2C1%2C2&keywords=test');
      });
    });

    describe('getSearchFromRemove', function () {
      it('withQuery passes query.getSearchFromRemove function that pops values from the location.search', function () {
        // given
        var history = (0, _history.createBrowserHistory)();
        history.push('/test?jours=0,1&keywords=test');
        var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
          _reactRouterDom.Router,
          { history: history },
          _react2.default.createElement(
            _reactRouterDom.Route,
            { path: '/test' },
            _react2.default.createElement(_utils.QueryRouterTest, null)
          )
        ));

        var _wrapper$find$props4 = wrapper.find('Test').props(),
            query = _wrapper$find$props4.query;

        // when


        var search = query.getSearchFromRemove('jours', '1');

        // then
        expect(search).toStrictEqual('?jours=0&keywords=test');
      });
    });
  });
});