'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash.invert');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.uniq');

var _lodash4 = _interopRequireDefault(_lodash3);

var _queryString = require('query-string');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _getObjectWithMappedKeys = require('./getObjectWithMappedKeys');

var _getObjectWithMappedKeys2 = _interopRequireDefault(_getObjectWithMappedKeys);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var useQuery = function useQuery(querySearchString) {
  var config = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var mapper = config.mapper,
      translater = config.translater;


  var invertedMapper = (0, _react.useMemo)(function () {
    return mapper && (0, _lodash2.default)(mapper);
  }, [mapper]);
  var params = (0, _react.useMemo)(function () {
    return (0, _queryString.parse)(querySearchString);
  }, [querySearchString]);

  var getSearchFromUpdate = (0, _react.useCallback)(function (notTranslatedQueryParamsUpdater) {
    var paramsUpdater = notTranslatedQueryParamsUpdater;
    if (translater) {
      paramsUpdater = translater(paramsUpdater);
    } else if (mapper) {
      paramsUpdater = (0, _getObjectWithMappedKeys2.default)(paramsUpdater, invertedMapper);
    }

    var paramsUpdaterKeys = Object.keys(paramsUpdater);
    var concatenatedQueryParamKeys = Object.keys(params).concat(paramsUpdaterKeys);
    var paramsKeys = (0, _lodash4.default)(concatenatedQueryParamKeys);

    var nextQueryParams = {};
    paramsKeys.forEach(function (paramsKey) {
      if (paramsUpdater[paramsKey]) {
        nextQueryParams[paramsKey] = paramsUpdater[paramsKey];
        return;
      }
      if (paramsUpdater[paramsKey] !== null && typeof params[paramsKey] !== 'undefined') {
        nextQueryParams[paramsKey] = params[paramsKey];
        return;
      }
      if (paramsUpdater[paramsKey] === '') {
        nextQueryParams[paramsKey] = null;
      }
    });

    var nextLocationSearch = (0, _queryString.stringify)(nextQueryParams);

    return '?' + nextLocationSearch;
  }, [params]);

  var getSearchFromAdd = (0, _react.useCallback)(function (key, value) {
    var nextValue = value;
    var previousValue = params[key];
    if (previousValue && previousValue.length) {
      var args = previousValue.split(',').concat([value]);
      args.sort();
      nextValue = args.join(',');
    } else if (typeof previousValue === 'undefined') {
      /* eslint-disable no-console */
      console.warn('Weird did you forget to mention this ' + key + ' query param in your withQuery hoc?');
    }

    return getSearchFromUpdate(_defineProperty({}, key, nextValue));
  }, [params]);

  var getSearchFromRemove = (0, _react.useCallback)(function (key, value) {
    var previousValue = params[key];
    if (previousValue && previousValue.length) {
      var nextValue = previousValue.replace(',' + value, '').replace(value, '');
      if (nextValue[0] === ',') {
        nextValue = nextValue.slice(1);
      }
      if (nextValue.trim() === "") {
        nextValue = null;
      }
      return getSearchFromUpdate(_defineProperty({}, key, nextValue));
    }
    if (typeof previousValue === 'undefined') {
      console.warn('Weird did you forget to mention this ' + key + ' query param in your withQuery hoc?');
    }
  }, [params]);

  var translatedParams = (0, _react.useMemo)(function () {
    if (translater) return translater(params);
    if (mapper) return (0, _getObjectWithMappedKeys2.default)(params, mapper);
    return params;
  }, [params]);

  return {
    getSearchFromAdd: getSearchFromAdd,
    getSearchFromRemove: getSearchFromRemove,
    getSearchFromUpdate: getSearchFromUpdate,
    params: params,
    translatedParams: translatedParams
  };
};

exports.default = useQuery;